#
# spec file for package unison
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           unison
Version:        2.40.61
Release:        3.1
Summary:        A file synchronization tool
Group:          Productivity/Networking/Other
License:        GPLv3+
Url:            http://www.cis.upenn.edu/~bcpierce/unison
Source0:        http://www.cis.upenn.edu/~bcpierce/unison/download/releases/stable/unison-%{version}.tar.gz
Source1:        http://www.cis.upenn.edu/~bcpierce/unison/download/releases/stable/unison-%{version}-manual.html
Source2:        %{name}.desktop
Source3:        %{name}.png
Patch0:         fix_makefile.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gtk2-devel ncurses-devel update-desktop-files
%if 0%{?suse_version} > 1020
BuildRequires:  lablgtk2-devel
%else
BuildRequires:  lablgtk2
%endif
AutoReqProv:    on

%description
Unison is a file synchronization tool for Unix and Windows. It allows
two replicas of a collection of files and directories to be stored on
different hosts (or different disks on the same host), modified
separately, then brought up to date by propagating the changes in each
replica to the other.

%prep
%setup -q
%patch0 -p 1

%build
# This package failed when testing with -Wl,-as-needed being default.
# So we disable it here, if you want to retest, just delete this comment and the line below.
export SUSE_ASNEEDED=0
%ifarch s390 s390x
make UISTYLE=gtk2 NATIVE=false THREADS=false
%else
make UISTYLE=gtk2 NATIVE=true THREADS=true
%endif

%install
install -m 755 -d %{buildroot}/%{_bindir}
install -m 755 %name %{buildroot}%{_bindir}
install -m 755 -d %{buildroot}/%{_prefix}/share/pixmaps
install -m 644 %{SOURCE3} %{buildroot}/%{_prefix}/share/pixmaps
install -m 644 %{SOURCE1} unison-manual.html
%suse_update_desktop_file -i %name Utility SyncUtility
%ifarch s390 s390x
# do not strip non-optimized builds
export NO_BRP_STRIP_DEBUG=true
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc BUGS.txt CONTRIB COPYING NEWS README ROADMAP.txt TODO.txt unison-manual.html
%{_datadir}/applications/*
%{_datadir}/pixmaps/unison.png
%{_bindir}/%{name}

%changelog
* Thu Mar 31 2011 saschpe@suse.de
- Spec file cleanup
  * Removed authors from description
  * Removed ctags dependency
* Sat Jan 29 2011 poletti.marco@gmail.com
- Update to version 2.40.61:
  * Add "BelowPath" patterns
  * Other fixes and improvements
- Update to version 2.40.1:
  * Unicode support
  * Partial transfer of directories
  * Experimental prococol for asyncronous file tranfers, hiding latency
  * Improve the performance of the rsync protocol
  * Many (!) other improvements and fixes
* Thu Oct  7 2010 aj@suse.de
- Fix build with ocaml 3.12 (patch unison-ocaml.patch).
* Wed Dec 16 2009 mhopf@novell.com
- Update to latest stable version 2.32.52
  * If Unison is interrupted during a directory transfer, it will now leave
    the partially transferred directory intact in a temporary location
  * Added experimental support for invoking an external file transfer tool for
    whole-file copies
  * Very preliminary support for triggering Unison from an external
    filesystem-watching utility.
  * Ignore one hour differences when deciding whether a file may have been
    updated (ignore daylight saving time changes under Windows)
  * Fixed slow performances when transferring a file using our rsync
    implementation from a 64-bit architecture to a 32-bit architecture
  * Case sensitivity information put in the archive (in a backward compatible
    way) and checked when the archive is loaded
  * Upgraded to GPL version 3
  * In repeat mode, don't save the archives when there is no update
  * Tons of bug fixes + small additions
* Fri Sep  4 2009 mhopf@novell.com
- Update to latest stable version 2.27.157
  * various small fixes.
* Mon Jun 29 2009 seife@suse.de
- Updated to latest stable version 2.27.149:
  * various small fixes all over the place
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Mon Jan 21 2008 seife@suse.de
- Updated to 2.27.57:
  * only some minor bugfixes (mistriggering assertions etc)
  * the patch vor bug 331513 is incorporated upstream
* Wed Nov 28 2007 seife@suse.de
- add an application icon for unison (bug 309880)
* Thu Oct 25 2007 seife@suse.de
- fix bug 331513 (one ":" too much in the profile)
* Sun Oct  7 2007 tsieden@suse.de
- Updated to 2.27.47:
  * Major rewrite and cleanup of the whole Mac OS X graphical user
    interface by Craig Federighi.
  * Ignore all-whitespace lines in preference files
  * Small fix to ctime (non-)handling in update detection under windows
    with fastcheck.
* Fri Aug 24 2007 tsieden@suse.de
- Updated to 2.27.29:
  * small bugfixes - mostly windows related
* Thu Aug 23 2007 tsieden@suse.de
- fix build (BuildRequires lablgtk2-devel only if suse_version >1020)
* Thu May 24 2007 ro@suse.de
- added lablgtk2-devel to buildreq
* Wed Apr 25 2007 mhopf@suse.de
- Updated to 2.27.24:
  * Backup functionality completely rewritten, removing bugs.
  * Several savety improvements: mountpoint checks, big deletes, missing
    symlink destinations
  * New forcepartial and preferpartial preferences
  * Improved debugging
  * Merge functionality partially rewritten
  * Reversed diff arguments.
  * Many bugfixes (fastcheck + daylight saving time under windows, 32/64
    bit cleanup, removing deadlocks, ...)
* Tue Apr 17 2007 seife@suse.de
- add ncurses-devel to buildrequires, to fix build on s390
* Wed Dec 13 2006 mhopf@suse.de
- added patch for no longer closing main window if subwindows open
- removed unison-gtk1 again
* Wed Dec  6 2006 seife@suse.de
- add unison-gtk1, a binary compiled against lablgtk
* Mon Sep 25 2006 mhopf@suse.de
- Update to version 2.17.1
- Completely rewritten backup function (actually working now)
- Ip V6 support
- Several bug fixes
* Thu Sep 21 2006 seife@suse.de
- switch to GTK2 / lablgtk2
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 10 2005 rommel@suse.de
- update to version 2.13.16 (includes all of our recent fixes)
- updated spec file, manual is available in html now
* Tue Mar 15 2005 ro@suse.de
- enable optimized compile on x86_64
* Tue Sep 14 2004 ro@suse.de
- fix build with ocaml-3.08 (from unison-hackers ml)
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 15 2003 adrian@suse.de
- add desktop file
* Tue Jul 22 2003 rommel@suse.de
- fixed "invalid escape sequence" error messages
- fixed %%install (not using make install anymore)
- compiling with thread support
* Tue May  6 2003 ro@suse.de
- fix tail calling syntax
* Mon Jan 27 2003 rommel@suse.de
- replaced pdf file (unreadable) with ps file
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon May 27 2002 ro@suse.de
- update to 2.9.1 makes it build with current ocaml
* Fri Sep 14 2001 grimmer@suse.de
- Update to 2.7.7, which fixes the following bugs (since
  2.7.1):
  * Fixed a silly bug that would reliably prevent the Unison
    client from starting in 2.7.4.
  * Bug fix (2.7.4): read the initial connection header one byte
    at a time, so that we don't block if the header is shorter
  than expected.
* Wed Aug 29 2001 grimmer@suse.de
- Update to 2.7.1 (see the NEWS file for changes)
- updated PDF manual to latest version
* Thu Aug 16 2001 grimmer@suse.de
- Initial package for SuSE Linux (version 2.6.59)
